@@ -54,7 +54,7 @@ import lombok.AllArgsConstructor;
 import lombok.Data;
 import lombok.NonNull;
 import lombok.RequiredArgsConstructor;
-import lombok.experimental.Wither;
+import lombok.With;
 
 @Data
 @AllArgsConstructor(access = AccessLevel.PRIVATE)
@@ -83,7 +83,7 @@ public class Folder {
     @NonNull
     private final String name;
 
-    @Wither
+    @With
     private final Type type;
 
     private String validity;
